@@ -22,41 +22,12 @@
 
 G_BEGIN_DECLS
 
-typedef enum
-{
-  GCAL_DATE_CHOOSER_DAY_NONE    = 1 << 0,
-  GCAL_DATE_CHOOSER_DAY_WEEKEND = 1 << 1,
-  GCAL_DATE_CHOOSER_DAY_HOLIDAY = 1 << 2,
-  GCAL_DATE_CHOOSER_DAY_MARKED  = 1 << 3
-} GcalDateChooserDayOptions;
-
 #define GCAL_TYPE_DATE_CHOOSER (gcal_date_chooser_get_type ())
 
 G_DECLARE_FINAL_TYPE (GcalDateChooser, gcal_date_chooser, GCAL, DATE_CHOOSER, AdwBin)
 
-typedef GcalDateChooserDayOptions (*GcalDateChooserDayOptionsCallback) (GcalDateChooser *self,
-                                                                        GDateTime       *date,
-                                                                        gpointer         user_data);
-
 GtkWidget*           gcal_date_chooser_new                       (void);
 
-GDateTime*           gcal_date_chooser_get_date                  (GcalDateChooser    *self);
-
-void                 gcal_date_chooser_set_date                  (GcalDateChooser    *self,
-                                                                  GDateTime          *date);
-
-void                 gcal_date_chooser_set_day_options_callback  (GcalDateChooser    *self,
-                                                                  GcalDateChooserDayOptionsCallback callback,
-                                                                  gpointer            data,
-                                                                  GDestroyNotify      destroy);
-
-void                 gcal_date_chooser_invalidate_day_options    (GcalDateChooser    *self);
-
-gboolean             gcal_date_chooser_get_no_month_change       (GcalDateChooser    *self);
-
-void                 gcal_date_chooser_set_no_month_change       (GcalDateChooser    *self,
-                                                                  gboolean            setting);
-
 gboolean             gcal_date_chooser_get_show_heading          (GcalDateChooser    *self);
 
 void                 gcal_date_chooser_set_show_heading          (GcalDateChooser    *self,
@@ -72,6 +43,21 @@ gboolean             gcal_date_chooser_get_show_week_numbers     (GcalDateChoose
 void                 gcal_date_chooser_set_show_week_numbers     (GcalDateChooser    *self,
                                                                   gboolean            setting);
 
+gboolean             gcal_date_chooser_get_show_selected_week    (GcalDateChooser    *self);
+
+void                 gcal_date_chooser_set_show_selected_week    (GcalDateChooser    *self,
+                                                                  gboolean            setting);
+
+gboolean             gcal_date_chooser_get_show_events           (GcalDateChooser    *self);
+
+void                 gcal_date_chooser_set_show_events           (GcalDateChooser    *self,
+                                                                  gboolean            setting);
+
+gboolean             gcal_date_chooser_get_split_month_year      (GcalDateChooser    *self);
+
+void                 gcal_date_chooser_set_split_month_year      (GcalDateChooser    *self,
+                                                                  gboolean            setting);
+
 G_END_DECLS
 
 #endif /* __GCAL_DATE_CHOOSER_H__ */
