@@ -33,6 +33,7 @@
 #include "gcal-month-view.h"
 #include "gcal-quick-add-popover.h"
 #include "gcal-search-button.h"
+#include "gcal-sync-indicator.h"
 #include "gcal-timeline.h"
 #include "gcal-timeline-subscriber.h"
 #include "gcal-toolbar-end.h"
@@ -81,8 +82,7 @@ typedef struct
 {
   gint                x;
   gint                y;
-  GDateTime          *start_date;
-  GDateTime          *end_date;
+  GcalRange          *range;
 } NewEventData;
 
 typedef struct
@@ -96,19 +96,22 @@ struct _GcalWindow
   AdwApplicationWindow parent;
 
   /* upper level widgets */
-  GtkWidget          *main_box;
+  GtkWidget              *main_box;
 
-  GtkWidget          *header_bar;
-  AdwToastOverlay    *overlay;
-  AdwViewStack       *views_stack;
-  GtkWidget          *week_view;
-  GtkWidget          *month_view;
-  GtkWidget          *agenda_view;
-  GtkWidget          *date_chooser;
-  GtkWidget          *action_bar;
-  GcalToolbarEnd     *toolbar_end;
+  GtkWidget              *header_bar;
+  AdwToastOverlay        *overlay;
+  AdwViewStack           *views_stack;
+  GtkWidget              *week_view;
+  GtkWidget              *month_view;
+  GtkWidget              *agenda_view;
+  GtkWidget              *date_chooser;
+  GtkWidget              *action_bar;
+  GcalSyncIndicator      *sync_indicator;
+  GcalToolbarEnd         *toolbar_end;
+  GcalToolbarEnd         *sidebar_toolbar_end;
+  AdwNavigationSplitView *split_view;
 
-  /* header_bar widets */
+  /* header_bar widgets */
   GtkWidget          *calendars_button;
   GtkWidget          *menu_button;
   GtkWidget          *views_switcher;
@@ -191,19 +194,15 @@ update_today_action_enabled (GcalWindow *window)
   switch (window->active_view)
     {
     case GCAL_WINDOW_VIEW_WEEK:
+    case GCAL_WINDOW_VIEW_MONTH:
       enabled = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
                 g_date_time_get_week_of_year (window->active_date) !=  g_date_time_get_week_of_year (now);
 
-      GCAL_TRACE_MSG ("Week: active date's week is %d, current week is %d",
+      GCAL_TRACE_MSG ("Active date's week is %d, current week is %d",
                       g_date_time_get_week_of_year (window->active_date),
                       g_date_time_get_week_of_year (now));
       break;
 
-    case GCAL_WINDOW_VIEW_MONTH:
-      enabled = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
-                g_date_time_get_month (window->active_date) != g_date_time_get_month (now);
-      break;
-
     default:
       enabled = TRUE;
       break;
@@ -292,7 +291,7 @@ recalculate_calendar_colors_css (GcalWindow *self)
     }
 
   new_css_data = g_strjoinv ("\n", new_css_snippets);
-  gtk_css_provider_load_from_data (self->colors_provider, new_css_data, -1);
+  gtk_css_provider_load_from_string (self->colors_provider, new_css_data);
 
   if (error)
     g_warning ("Error creating custom stylesheet. %s", error->message);
@@ -324,6 +323,17 @@ hide_widget (GtkWidget *widget)
   gtk_widget_set_visible (widget, FALSE);
 }
 
+static char *
+content_title (GcalWindow     *self,
+               GcalWindowView  active_view)
+{
+  /* We check for NULL so we get the right page name during initialization */
+  if (active_view == GCAL_WINDOW_VIEW_WEEK)
+    return g_strdup (_("Week"));
+  else
+    return g_strdup (_("Month"));
+}
+
 /*
  * Callbacks
  */
@@ -333,9 +343,9 @@ on_show_calendars_action_activated (GSimpleAction *action,
                                     GVariant      *param,
                                     gpointer       user_data)
 {
-  GcalWindow *window = GCAL_WINDOW (user_data);
+  GcalWindow *self = GCAL_WINDOW (user_data);
 
-  gtk_widget_set_visible (window->calendar_management_dialog, TRUE);
+  adw_dialog_present (ADW_DIALOG (self->calendar_management_dialog), GTK_WIDGET (self));
 }
 
 static void
@@ -406,8 +416,18 @@ on_window_new_event_cb (GSimpleAction *action,
   default_calendar = gcal_manager_get_default_calendar (manager);
   event = gcal_event_new (default_calendar, comp, NULL);
 
+  adw_dialog_present (ADW_DIALOG (self->event_editor), GTK_WIDGET (self));
   gcal_event_editor_dialog_set_event (self->event_editor, event, TRUE);
-  gtk_widget_set_visible (GTK_WIDGET (self->event_editor), TRUE);
+}
+
+static void
+on_window_open_date_time_settings_cb (GSimpleAction *action,
+                                      GVariant      *param,
+                                      gpointer       user_data)
+{
+  GDBusConnection *connection = g_application_get_dbus_connection (g_application_get_default ());
+
+  gcal_utils_launch_gnome_settings (connection, "datetime", NULL);
 }
 
 static void
@@ -415,9 +435,9 @@ on_window_open_online_accounts_cb (GSimpleAction *action,
                                    GVariant      *param,
                                    gpointer       user_data)
 {
-  GApplication *application = g_application_get_default ();
+  GDBusConnection *connection = g_application_get_dbus_connection (g_application_get_default ());
 
-  gcal_utils_launch_online_accounts_panel (g_application_get_dbus_connection (application), NULL, NULL);
+  gcal_utils_launch_gnome_settings (connection, "online-accounts", NULL);
 }
 
 static void
@@ -537,50 +557,50 @@ set_new_event_mode (GcalWindow *window,
 /* new-event interaction: second variant */
 static void
 show_new_event_widget (GcalView   *view,
-                       GDateTime  *start_span,
-                       GDateTime  *end_span,
+                       GcalRange  *range,
                        gdouble     x,
                        gdouble     y,
                        GcalWindow *window)
 {
+  graphene_point_t p;
   GdkRectangle rect;
-  gdouble out_x;
-  gdouble out_y;
 
   GCAL_ENTRY;
 
+  g_assert (range != NULL);
+
   /* 1st and 2nd steps */
   set_new_event_mode (window, TRUE);
 
   if (window->event_creation_data != NULL)
     {
-      g_clear_pointer (&window->event_creation_data->start_date, g_date_time_unref);
-      g_clear_pointer (&window->event_creation_data->end_date, g_date_time_unref);
+      g_clear_pointer (&window->event_creation_data->range, gcal_range_unref);
       g_clear_pointer (&window->event_creation_data, g_free);
     }
 
   window->event_creation_data = g_new0 (NewEventData, 1);
   window->event_creation_data->x = x;
   window->event_creation_data->y = y;
-  window->event_creation_data->start_date = g_date_time_ref (start_span);
-  window->event_creation_data->end_date = end_span ? g_date_time_ref (end_span) : NULL;
+  window->event_creation_data->range = gcal_range_ref (range);
 
   g_debug ("Quick add popover position (%f, %f)", x, y);
 
   /* Setup the quick add popover's dates */
-  gcal_quick_add_popover_set_date_start (GCAL_QUICK_ADD_POPOVER (window->quick_add_popover), start_span);
-  gcal_quick_add_popover_set_date_end (GCAL_QUICK_ADD_POPOVER (window->quick_add_popover), end_span);
+  gcal_quick_add_popover_set_range (GCAL_QUICK_ADD_POPOVER (window->quick_add_popover),
+                                    window->event_creation_data->range);
 
   /* Position and place the quick add popover */
-  gtk_widget_translate_coordinates (window->views[window->active_view],
-                                    GTK_WIDGET (window),
-                                    x, y,
-                                    &out_x,
-                                    &out_y);
+  if (!gtk_widget_compute_point (window->views[window->active_view],
+                                 GTK_WIDGET (window),
+                                 &GRAPHENE_POINT_INIT (x, y),
+                                 &p))
+    {
+      g_assert_not_reached ();
+    }
 
   /* Place popover over the given (x,y) position */
-  rect.x = out_x;
-  rect.y = out_y;
+  rect.x = p.x;
+  rect.y = p.y;
   rect.width = 1;
   rect.height = 1;
 
@@ -600,31 +620,33 @@ close_new_event_widget (GtkButton *button,
 static void
 edit_event (GcalQuickAddPopover *popover,
             GcalEvent           *event,
-            GcalWindow          *window)
+            GcalWindow          *self)
 {
-  gcal_event_editor_dialog_set_event (window->event_editor, event, TRUE);
-  gtk_widget_set_visible (GTK_WIDGET (window->event_editor), TRUE);
+  adw_dialog_present (ADW_DIALOG (self->event_editor), GTK_WIDGET (self));
+  gcal_event_editor_dialog_set_event (self->event_editor, event, TRUE);
 }
 
 static void
-create_event_detailed_cb (GcalView *view,
-                          gpointer  start_span,
-                          gpointer  end_span,
-                          gpointer  user_data)
+create_event_detailed_cb (GcalView   *view,
+                          GcalRange  *range,
+                          GcalWindow *self)
 {
-  GcalWindow *window = GCAL_WINDOW (user_data);
+  g_autoptr (GDateTime) range_start = NULL;
+  g_autoptr (GDateTime) range_end = NULL;
   GcalCalendar *default_calendar;
   GcalManager *manager;
   ECalComponent *comp;
   GcalEvent *event;
 
-  manager = gcal_context_get_manager (window->context);
-  comp = build_component_from_details ("", start_span, end_span);
+  manager = gcal_context_get_manager (self->context);
+  range_start = gcal_range_get_start (range);
+  range_end = gcal_range_get_end (range);
+  comp = build_component_from_details ("", range_start, range_end);
   default_calendar = gcal_manager_get_default_calendar (manager);
   event = gcal_event_new (default_calendar, comp, NULL);
 
-  gcal_event_editor_dialog_set_event (window->event_editor, event, TRUE);
-  gtk_widget_set_visible (GTK_WIDGET (window->event_editor), TRUE);
+  adw_dialog_present (ADW_DIALOG (self->event_editor), GTK_WIDGET (self));
+  gcal_event_editor_dialog_set_event (self->event_editor, event, TRUE);
 
   g_clear_object (&comp);
 }
@@ -641,8 +663,8 @@ event_preview_cb (GcalEventWidget        *event_widget,
     {
     case GCAL_EVENT_PREVIEW_ACTION_EDIT:
       event = gcal_event_widget_get_event (event_widget);
+      adw_dialog_present (ADW_DIALOG (self->event_editor), GTK_WIDGET (self));
       gcal_event_editor_dialog_set_event (self->event_editor, event, FALSE);
-      gtk_window_present (GTK_WINDOW (self->event_editor));
       break;
 
     case GCAL_EVENT_PREVIEW_ACTION_NONE:
@@ -778,8 +800,7 @@ gcal_window_finalize (GObject *object)
 
   if (window->event_creation_data)
     {
-      g_clear_pointer (&window->event_creation_data->start_date, g_date_time_unref);
-      g_clear_pointer (&window->event_creation_data->end_date, g_date_time_unref);
+      g_clear_pointer (&window->event_creation_data->range, gcal_range_unref);
       g_clear_pointer (&window->event_creation_data, g_free);
     }
 
@@ -856,7 +877,9 @@ gcal_window_constructed (GObject *object)
   g_object_bind_property (self, "context", self->date_chooser, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->event_editor, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->quick_add_popover, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->sync_indicator, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->toolbar_end, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->sidebar_toolbar_end, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
 
   /* CSS */
   load_css_providers (self);
@@ -989,6 +1012,7 @@ gcal_window_class_init (GcalWindowClass *klass)
   g_type_ensure (GCAL_TYPE_MANAGER);
   g_type_ensure (GCAL_TYPE_MONTH_VIEW);
   g_type_ensure (GCAL_TYPE_QUICK_ADD_POPOVER);
+  g_type_ensure (GCAL_TYPE_SYNC_INDICATOR);
   g_type_ensure (GCAL_TYPE_TOOLBAR_END);
   g_type_ensure (GCAL_TYPE_WEATHER_SETTINGS);
   g_type_ensure (GCAL_TYPE_WEEK_VIEW);
@@ -1046,6 +1070,9 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, quick_add_popover);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendar_management_dialog);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, overlay);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, sidebar_toolbar_end);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, split_view);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, sync_indicator);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, toolbar_end);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_stack);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_switcher);
@@ -1055,12 +1082,13 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, view_changed);
 
   /* Event creation related */
-  gtk_widget_class_bind_template_callback (widget_class, edit_event);
-  gtk_widget_class_bind_template_callback (widget_class, create_event_detailed_cb);
-  gtk_widget_class_bind_template_callback (widget_class, show_new_event_widget);
   gtk_widget_class_bind_template_callback (widget_class, close_new_event_widget);
+  gtk_widget_class_bind_template_callback (widget_class, content_title);
+  gtk_widget_class_bind_template_callback (widget_class, create_event_detailed_cb);
   gtk_widget_class_bind_template_callback (widget_class, day_selected);
+  gtk_widget_class_bind_template_callback (widget_class, edit_event);
   gtk_widget_class_bind_template_callback (widget_class, event_activated);
+  gtk_widget_class_bind_template_callback (widget_class, show_new_event_widget);
 
   /* Edit dialog related */
   gtk_widget_class_bind_template_callback (widget_class, on_event_editor_dialog_remove_event_cb);
@@ -1073,6 +1101,7 @@ gcal_window_init (GcalWindow *self)
     {"change-view", on_view_action_activated, "i" },
     {"next-date", on_window_next_date_activated_cb },
     {"new-event", on_window_new_event_cb },
+    {"open-date-time-settings", on_window_open_date_time_settings_cb },
     {"open-online-accounts", on_window_open_online_accounts_cb },
     {"previous-date", on_window_previous_date_activated_cb },
     {"show-calendars", on_show_calendars_action_activated },
@@ -1135,10 +1164,16 @@ gcal_window_set_search_query (GcalWindow  *self,
                               const gchar *query)
 {
   GtkWidget *search_button;
+  GcalToolbarEnd *toolbar_end;
 
   g_return_if_fail (GCAL_IS_WINDOW (self));
 
-  search_button = gcal_toolbar_end_get_search_button (self->toolbar_end);
+  if (adw_navigation_split_view_get_collapsed (self->split_view))
+    toolbar_end = self->sidebar_toolbar_end;
+  else
+    toolbar_end = self->toolbar_end;
+
+  search_button = gcal_toolbar_end_get_search_button (toolbar_end);
   gcal_search_button_search (GCAL_SEARCH_BUTTON (search_button), query);
 }
 
