@@ -275,7 +275,7 @@ on_scroll_controller_scroll_begin_cb (GtkEventControllerScroll *controller,
   if (self->pointer_position_valid)
     view_center_y = self->pointer_position_y;
   else
-    view_center_y = gtk_widget_get_allocated_height (self->scrolled_window) / 2.0;
+    view_center_y = gtk_widget_get_height (self->scrolled_window) / 2.0;
 
   begin_zoom (self, view_center_y);
 }
@@ -318,7 +318,7 @@ on_scroll_controller_scroll_cb (GtkEventControllerScroll *controller,
   if (self->pointer_position_valid)
     view_center_y = self->pointer_position_y;
   else
-    view_center_y = gtk_widget_get_allocated_height (self->scrolled_window) / 2.0;
+    view_center_y = gtk_widget_get_height (self->scrolled_window) / 2.0;
 
   if (discrete)
     begin_zoom (self, view_center_y);
@@ -503,6 +503,7 @@ gcal_week_view_add_event (GcalTimelineSubscriber *subscriber,
 
 static void
 gcal_week_view_update_event (GcalTimelineSubscriber *subscriber,
+                             GcalEvent              *old_event,
                              GcalEvent              *event)
 {
   GcalWeekView *self = GCAL_WEEK_VIEW (subscriber);
@@ -510,7 +511,7 @@ gcal_week_view_update_event (GcalTimelineSubscriber *subscriber,
 
   GCAL_ENTRY;
 
-  event_id = gcal_event_get_uid (event);
+  event_id = gcal_event_get_uid (old_event);
   gcal_week_header_remove_event (GCAL_WEEK_HEADER (self->header), event_id);
   gcal_week_grid_remove_event (GCAL_WEEK_GRID (self->week_grid), event_id);
 
