@@ -401,17 +401,13 @@ build_component_from_details (const gchar *summary,
                               GDateTime   *initial_date,
                               GDateTime   *final_date)
 {
-  GcalApplication *application;
-  GcalContext *context;
-  ECalComponent *event;
-  ECalComponentDateTime *dt;
-  ECalComponentText *summ;
-  ICalTimezone *tz;
-  ICalTime *itt;
-  gboolean all_day;
+  ECalComponent *event = NULL;
+  ECalComponentDateTime *dt = NULL;
+  ECalComponentText *summ = NULL;
+  ICalTimezone *tz = NULL;
+  ICalTime *itt = NULL;
+  gboolean all_day = FALSE;
 
-  application = GCAL_APPLICATION (g_application_get_default ());
-  context = gcal_application_get_context (application);
   event = e_cal_component_new ();
   e_cal_component_set_new_vtype (event, E_CAL_COMPONENT_EVENT);
 
@@ -431,9 +427,8 @@ build_component_from_details (const gchar *summary,
     }
   else
     {
-      GTimeZone *zone;
-
-      zone = gcal_context_get_timezone (context);
+      g_autoptr (GTimeZone) zone = NULL;
+      zone = gcal_util_get_app_timezone_or_local ();
       tz = gcal_timezone_to_icaltimezone (zone);
     }
 
@@ -515,16 +510,12 @@ icaltime_compare_with_current (const ICalTime *date1,
                                const ICalTime *date2,
                                time_t         *current_time_t)
 {
-  GcalApplication *application;
-  GcalContext *context;
-  GTimeZone *zone;
+  g_autoptr (GTimeZone) zone = NULL;
   ICalTimezone *zone1, *zone2;
   gint result = 0;
   time_t start1, start2, diff1, diff2;
 
-  application = GCAL_APPLICATION (g_application_get_default ());
-  context = gcal_application_get_context (application);
-  zone = gcal_context_get_timezone (context);
+  zone = gcal_util_get_app_timezone_or_local ();
 
   zone1 = i_cal_time_get_timezone (date1);
   if (!zone1)
@@ -668,75 +659,6 @@ e_utf8_strftime_fix_am_pm (gchar *str,
   return sz;
 }
 
-
-/**
- * fix_popover_menu_icons:
- * @window: a #GtkPopover
- *
- * Hackish code that inspects the popover's children,
- * retrieve the hidden GtkImage buried under lots of
- * widgets, and make it visible again.
- *
- * Hopefully, we'll find a better way to do this in
- * the long run.
- *
- */
-void
-fix_popover_menu_icons (GtkPopover *popover)
-{
-  GtkWidget *popover_stack;
-  GtkWidget *menu_section;
-  GtkWidget *menu_section_box;
-  GtkWidget *widget;
-  GtkWidget *child;
-
-  /* GtkScrolledWindow */
-  widget = gtk_popover_get_child (GTK_POPOVER (popover));
-
-  /* GtkViewport */
-  widget = gtk_scrolled_window_get_child (GTK_SCROLLED_WINDOW (widget));
-
-  /* GtkStack */
-  popover_stack = gtk_viewport_get_child (GTK_VIEWPORT (widget));
-
-  menu_section = gtk_widget_get_first_child (popover_stack);
-
-	/**
-	 * Get the unique box's children.
-	 */
-  menu_section_box = gtk_widget_get_first_child (menu_section);
-
-  gtk_widget_add_css_class (menu_section_box, "calendars-list");
-
-  /**
-   * Iterate through the GtkModelButtons inside the menu section box.
-   */
-  for (child = gtk_widget_get_first_child (menu_section_box);
-       child;
-       child = gtk_widget_get_next_sibling (child))
-    {
-      GtkWidget *child2;
-
-      /**
-       * Since there is no guarantee that the first child is
-       * the GtkImage we're looking for, we have to iterate
-       * through the children and check if the types match.
-       */
-      for (child2 = gtk_widget_get_first_child (child);
-           child2;
-           child2 = gtk_widget_get_next_sibling (child2))
-        {
-          if (GTK_IS_IMAGE (child2))
-            {
-              gtk_widget_add_css_class (child2, "calendar-color-image");
-              gtk_widget_set_margin_end (child2, 12);
-              gtk_widget_set_visible (child2, TRUE);
-              break;
-            }
-        }
-    }
-}
-
 /**
  * get_source_parent_name_color:
  * @manager: a #GcalManager
@@ -1328,3 +1250,42 @@ gcal_util_translate_time_string (const gchar *str)
 
   return res;
 }
+
+/**
+ * gcal_util_get_app_timezone_or_local:
+ *
+ * Returns a new reference to the application context timezone. If
+ * g_application_get_default() returns null, because there's no default
+ * application, it'll return a new local timezone created with
+ * g_timezone_new_local().
+ *
+ * Returns: (transfer full): a #GTimeZone
+ */
+GTimeZone *
+gcal_util_get_app_timezone_or_local ()
+{
+  GcalApplication *application = NULL;
+  GcalContext *context = NULL;
+
+  application = GCAL_APPLICATION (g_application_get_default ());
+  if (!application)
+    return g_time_zone_new_local ();
+
+  context = gcal_application_get_context (application);
+  return g_time_zone_ref (gcal_context_get_timezone (context));
+}
+
+/**
+ * gcal_is_valid_event_name:
+ * @event_name: the name of the event to check
+ *
+ * Check if the event name is valid
+ *
+ * Returns: %TRUE if the name is valid, %FALSE otherwise.
+ */
+gboolean
+gcal_is_valid_event_name (const gchar *event_name)
+{
+  g_autofree gchar *aux = g_strstrip (g_strdup (event_name));
+  return g_utf8_strlen (aux, -1) > 0;
+}
